@@ -6,7 +6,9 @@
 I/O operations
 ==============
 """
-from typing import Any, Iterable, Optional, Sequence, Tuple, Union
+from __future__ import annotations
+
+from typing import Any, Iterable, Sequence
 import collections
 import json
 import logging
@@ -19,7 +21,7 @@ import numpy
 import zarr
 
 from . import dataset, meta, sync
-from .typing import ArrayLike
+from .type_hints import ArrayLike
 
 #: Block size limit used with dask arrays. (128 MiB)
 BLOCK_SIZE_LIMIT = 134217728
@@ -97,7 +99,7 @@ def _to_zarr(array: dask.array.core.Array, mapper: fsspec.FSMap, path: str,
 
 def write_zattrs(
     dirname: str,
-    variable: Union[meta.Variable, dataset.Variable],
+    variable: meta.Variable | dataset.Variable,
     fs: fsspec.AbstractFileSystem,
 ) -> None:
     """Write the attributes of a variable to a Zarr dataset.
@@ -112,11 +114,11 @@ def write_zattrs(
     attrs[DIMENSIONS] = variable.dimensions
     path = fs.sep.join((dirname, variable.name, ZATTRS))
     with fs.open(path, mode='w') as stream:
-        json.dump(attrs, stream, indent=2)
+        json.dump(attrs, stream, indent=2)  # type: ignore[arg-type]
 
 
 def write_zarr_variable(
-    args: Tuple[str, dataset.Variable],
+    args: tuple[str, dataset.Variable],
     dirname: str,
     fs: fsspec.AbstractFileSystem,
 ) -> None:
@@ -148,11 +150,40 @@ def write_zarr_variable(
     write_zattrs(dirname, variable, fs)
 
 
+def _write_meta(
+    ds: dataset.Dataset,
+    dirname: str,
+    fs: fsspec.AbstractFileSystem,
+) -> None:
+    """Write the metadata of a dataset to a Zarr dataset.
+
+    Args:
+        ds: The dataset to process.
+        dirname: The storage directory of the Zarr dataset.
+        fs: The file system on which the Zarr dataset is stored.
+    """
+    path = fs.sep.join((dirname, ZATTRS))
+    attrs = collections.OrderedDict(item.get_config() for item in ds.attrs)
+    with fs.open(path, mode='w') as stream:
+        json.dump(attrs, stream, indent=2)  # type: ignore[arg-type]
+
+    path = fs.sep.join((dirname, ZGROUP))
+    with fs.open(path, mode='w') as stream:
+        json.dump(
+            {'zarr_format': 2},
+            stream,  # type: ignore[arg-type]
+            indent=2,
+        )
+    zarr.consolidate_metadata(fs.get_mapper(dirname))  # type: ignore[arg-type]
+    fs.invalidate_cache(dirname)
+
+
 def write_zarr_group(
     ds: dataset.Dataset,
     dirname: str,
     fs: fsspec.AbstractFileSystem,
     synchronizer: sync.Sync,
+    parallel: bool = True,
 ) -> None:
     """Write a partition to a Zarr group.
 
@@ -161,28 +192,24 @@ def write_zarr_group(
         dirname: The name of the partition.
         fs: The file system that the partition is stored on.
         synchronizer: The instance handling access to critical resources.
+        parallel: Whether to write the variables in parallel using Dask.
     """
-    with dask.distributed.worker_client() as client:
-        iterables = [(name, client.scatter(variable))
-                     for name, variable in ds.variables.items()]
-        futures = client.map(write_zarr_variable,
-                             iterables,
-                             dirname=dirname,
-                             fs=fs)
-        execute_transaction(client, synchronizer, futures)
+    if parallel:
+        with dask.distributed.worker_client() as client:
+            iterables = [(name, client.scatter(variable))
+                         for name, variable in ds.variables.items()]
+            futures = client.map(write_zarr_variable,
+                                 iterables,
+                                 dirname=dirname,
+                                 fs=fs)
+            execute_transaction(client, synchronizer, futures)
+        _write_meta(ds, dirname, fs)
+        return
 
-    path = fs.sep.join((dirname, ZATTRS))
-    attrs = collections.OrderedDict(item.get_config() for item in ds.attrs)
-    with fs.open(path, mode='w') as stream:
-        json.dump(attrs, stream, indent=2)
-
-    path = fs.sep.join((dirname, ZGROUP))
-    with fs.open(path, mode='w') as stream:
-        json.dump({'zarr_format': 2}, stream, indent=2)
-
-    zarr.consolidate_metadata(fs.get_mapper(dirname))
-    # Invalidate any cached directory information.
-    fs.invalidate_cache(dirname)
+    for name, variable in ds.variables.items():
+        write_zarr_variable((name, variable), dirname, fs)
+    _write_meta(ds, dirname, fs)
+    return
 
 
 def open_zarr_array(array: zarr.Array, name: str) -> dataset.Variable:
@@ -201,7 +228,7 @@ def open_zarr_array(array: zarr.Array, name: str) -> dataset.Variable:
 def open_zarr_group(
         dirname,
         fs: fsspec.AbstractFileSystem,
-        selected_variables: Optional[Iterable[str]] = None) -> dataset.Dataset:
+        selected_variables: Iterable[str] | None = None) -> dataset.Dataset:
     """Open a Zarr group stored in a partition.
 
     Args:
@@ -214,7 +241,8 @@ def open_zarr_group(
         The zarr group stored in the partition.
     """
     _LOGGER.debug('Opening Zarr group %r', dirname)
-    store: zarr.Group = zarr.open_consolidated(fs.get_mapper(dirname))
+    store: zarr.Group = zarr.open_consolidated(  # type: ignore[arg-type]
+        fs.get_mapper(dirname), )
     # Ignore unknown variables to retain.
     selected_variables = set(selected_variables) & set(
         store) if selected_variables is not None else set(store)
@@ -272,7 +300,9 @@ def del_zarr_array(
     path = fs.sep.join((dirname, name))
     if fs.exists(path):
         fs.rm(path, recursive=True)
-        zarr.consolidate_metadata(fs.get_mapper(dirname))
+        zarr.consolidate_metadata(
+            fs.get_mapper(dirname),  # type: ignore[arg-type]
+        )
         # Invalidate any cached directory information.
         fs.invalidate_cache(dirname)
 
@@ -304,4 +334,4 @@ def add_zarr_array(
         store=store,
         filters=variable.filters)
     write_zattrs(dirname, variable, fs)
-    zarr.consolidate_metadata(fs.get_mapper(dirname))
+    zarr.consolidate_metadata(fs.get_mapper(dirname))  # type: ignore[arg-type]
