@@ -6,22 +6,11 @@
 Internal utilities
 ==================
 """
-from typing import (
-    Any,
-    Callable,
-    Iterable,
-    Iterator,
-    List,
-    Optional,
-    Sequence,
-    Set,
-    Tuple,
-    Union,
-)
+from __future__ import annotations
+
+from typing import Any, Callable, Iterator, Sequence
 import asyncio
-import functools
 import itertools
-import operator
 import os
 
 import dask.distributed
@@ -65,7 +54,7 @@ def get_client() -> dask.distributed.Client:
 
 
 def get_fs(
-    filesystem: Optional[Union[fsspec.AbstractFileSystem, str]] = None
+    filesystem: fsspec.AbstractFileSystem | str | None = None
 ) -> fsspec.AbstractFileSystem:
     """Return the file system object from the input.
 
@@ -89,7 +78,7 @@ def fs_walk(
     fs: fsspec.AbstractFileSystem,
     path: str,
     sort: bool = False,
-) -> Iterator[Tuple[str, List[str], List[str]]]:
+) -> Iterator[tuple[str, list[str], list[str]]]:
     """Return the list of files and directories in a directory.
 
     Args:
@@ -142,7 +131,7 @@ def normalize_path(fs: fsspec.AbstractFileSystem, path: str) -> str:
     """
     # pylint: disable=protected-access
     # There is no public method to perform this operation.
-    path = fs._strip_protocol(path)
+    path = fs._strip_protocol(path)  # type: ignore[return-value]
     # pylint: enable=protected-access
     if path == '':
         path = fs.sep
@@ -151,7 +140,7 @@ def normalize_path(fs: fsspec.AbstractFileSystem, path: str) -> str:
     return path
 
 
-async def _available_workers(client: dask.distributed.Client) -> Set[str]:
+async def _available_workers(client: dask.distributed.Client) -> set[str]:
     """Get the list of available workers.
     Args:
         client: Client connected to the Dask cluster.
@@ -163,6 +152,7 @@ async def _available_workers(client: dask.distributed.Client) -> Set[str]:
         info = client.scheduler_info()
         assert client.scheduler is not None
         tasks = await client.scheduler.processing(workers=None)
+        assert tasks is not None
         result = set(info['workers']) - {k
                                          for k, v in tasks.items()
                                          if v}  # type: ignore[arg-type]
@@ -174,8 +164,8 @@ async def _available_workers(client: dask.distributed.Client) -> Set[str]:
 def calculation_stream(func: Callable,
                        seq: Iterator,
                        *args,
-                       max_workers: Optional[int] = None,
-                       **kwargs) -> List[Any]:
+                       max_workers: int | None = None,
+                       **kwargs) -> list[Any]:
     """Streams the calculation to almost n workers.
 
     Args:
@@ -193,7 +183,7 @@ def calculation_stream(func: Callable,
     client = get_client()
     completed = dask.distributed.as_completed()
 
-    def n_workers(max_workers: Optional[int]) -> int:
+    def n_workers(max_workers: int | None) -> int:
         """Limit the number of workers.
 
         Args:
@@ -204,7 +194,7 @@ def calculation_stream(func: Callable,
         """
         return max_workers or len(client.scheduler_info()['workers'])
 
-    workers: Set[str] = set()
+    workers: set[str] = set()
 
     result = []
     iterate = True
@@ -241,7 +231,7 @@ def calculation_stream(func: Callable,
 
 
 def split_sequence(sequence: Sequence[Any],
-                   sections: Optional[int] = None) -> Iterator[Sequence[Any]]:
+                   sections: int | None = None) -> Iterator[Sequence[Any]]:
     """Split a sequence into sections.
 
     Args:
@@ -262,15 +252,3 @@ def split_sequence(sequence: Sequence[Any],
         itertools.accumulate([0] + extras * [size + 1] +
                              (sections - extras) * [size]))
     yield from (sequence[item:div[ix + 1]] for ix, item in enumerate(div[:-1]))
-
-
-def prod(iterable: Iterable) -> int:
-    """Get the product of an iterable.
-
-    Args:
-        iterable: An iterable.
-
-    Returns:
-        The product of the iterable.
-    """
-    return functools.reduce(operator.mul, iterable, 1)
