@@ -24,9 +24,9 @@ import numpy
 import xarray
 import zarr
 
-from . import meta, utilities
+from . import mathematics, meta
 from .meta import Attribute
-from .typing import ArrayLike, NDArray, NDMaskedArray
+from .type_hints import ArrayLike, NDArray, NDMaskedArray
 
 
 def _dimensions_repr(dimensions: dict[str, int]) -> str:
@@ -242,7 +242,7 @@ class Variable:
     @property
     def size(self: Any) -> int:
         """Return the size of the variable."""
-        return utilities.prod(self.shape)
+        return mathematics.prod(self.shape)
 
     @property
     def nbytes(self):
@@ -259,22 +259,17 @@ class Variable:
                              self.attrs, self.compressor, self.fill_value,
                              self.filters)
 
-    def have_same_properties(self, other: Variable) -> bool:
-        """Return true if this instance and the other variable have the same
-        properties."""
-        return self.metadata() == other.metadata()
-
     def persist(self, **kwargs) -> Variable:
         """Persist the variable data into memory.
 
         Args:
             **kwargs: Keyword arguments passed to
-                :func:`dask.array.Array.persist`.
+                :meth:`dask.array.Array.persist`.
 
         Returns:
             The variable
         """
-        self.array = dask.base.persist(self.data, **kwargs)
+        self.array = dask.base.persist(self.data, **kwargs)  # type: ignore
         return self
 
     @property
@@ -344,7 +339,7 @@ class Variable:
 
         Args:
             **kwargs: Keyword arguments passed to
-            :func:`dask.array.Array.compute`.
+                :meth:`dask.array.Array.compute`.
         """
         (values, ) = dask.base.compute(self.array, traverse=False, **kwargs)
         return values if self.fill_value is None else numpy.ma.masked_equal(
@@ -514,6 +509,20 @@ class Variable:
                              self.attrs, self.compressor, self.fill_value,
                              self.filters)
 
+    def rechunk(self, **kwargs) -> Variable:
+        """Rechunk the variable.
+
+        Args:
+            **kwargs: Keyword arguments passed to
+                :func:`dask.array.rechunk`
+
+        Returns:
+            The variable.
+        """
+        return self._new(self.name, self.array.rechunk(**kwargs),
+                         self.dimensions, self.attrs, self.compressor,
+                         self.fill_value, self.filters)
+
     def to_xarray(self) -> xarray.Variable:
         """Convert the variable to an xarray.Variable.
 
@@ -561,7 +570,7 @@ class Variable:
 
         .. seealso::
 
-            :func:`dask.array.core.asarray`
+            :func:`dask.array.asarray`
         """
         return self.array
 
@@ -589,7 +598,7 @@ class Variable:
         """Returns whether the Dask graph can be optimized.
 
         .. seealso::
-            :func:`dask.array.Array.__dask_optimize__`
+            :meth:`dask.array.Array.__dask_optimize__`
         """
         return dask.array.core.Array.__dask_optimize__(dsk, keys, **kwargs)
 
